/*
 * This file is part of OpenTTD.
 * OpenTTD is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 2.
 * OpenTTD is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
 */

/** @file highscore_widget.h Types related to the highscore widgets. */

#ifndef WIDGETS_HIGHSCORE_WIDGET_H
#define WIDGETS_HIGHSCORE_WIDGET_H

/** Widgets of the #EndGameHighScoreBaseWindow class and #HighScoreWindow class. */
enum HighscoreWidgets : WidgetID {
	WID_H_BACKGROUND, ///< Background of the window.
};

#endif /* WIDGETS_HIGHSCORE_WIDGET_H */
